(define-module (ui rd_users ajax)
               :use-module (alterator ajax)
               :use-module (alterator woo)
               :use-module (alterator card-index)
               :export (init))

; Widgets to hide
(define widgets '(
									"btn_profile_enable"
									"btn_profile_disable"
									"form_profile_options"
									))

; Checkboxes
(define checkboxes '(
										 "check_profile_autostart"
										 ))

; Reset interface
(define (reset-interface)
		(for-each (lambda(p) (form-update-visibility p #f)) widgets)
    (for-each (lambda(p) (form-update-value p #f)) checkboxes))

; Interface initialization
(define (init-interface) 
	(reset-interface)
	(form-update-visibility '("form_user_edit") #f)
	; Ask for available users
	(catch/message (lambda() (form-update-enum "list_users" (woo "users" "/rd/list_users" 'language (form-value "language"))))))

; Bind profiles to specific user
(define (user-edit)
	(reset-interface)
	; Get settings for user
	(let* ((user (f-get-ci-value "list_users"))
				 (profiles-disabled (woo "users" "/rd/list_profiles_disabled" 'user user 'language (form-value "language")))
				 (profiles-enabled (woo "users" "/rd/list_profiles_enabled" 'user user 'language (form-value "language"))))
		(form-update-value "label_user" user)
		(form-update-enum "list_profiles_disabled" profiles-disabled)
		(form-update-enum "list_profiles_enabled" profiles-enabled)
		(form-update-visibility '("form_user_edit") #t)))

; Disabled profile selected
(define (disabled-selected)
	(form-update-visibility "btn_profile_enable" #t))

; Enabled profile selected
(define (enabled-selected)
	(let* ((user (f-get-ci-value "list_users"))
				 (profile (f-get-ci-value "list_profiles_enabled"))
				 (profile_options (woo "users" "/rd/read_profile_options" 'user user 'profile profile 'language (form-value "language"))))
		(for-each (lambda(p) (form-update-value p #f)) checkboxes)
		(form-update-value-list checkboxes profile_options))
	(form-update-visibility '("btn_profile_disable" "form_profile_options") #t))

; Grant profile to user
(define (profile-enable)
	(let*
		; Look profile name
		((profile (f-get-ci-value "list_profiles_disabled"))
		 ; Look user name
		 (user (f-get-ci-value "list_users")))
		(and
			; Enable profile for user
			(catch/message (lambda() (woo "users" "/rd/enable_profile" 'user user 'profile profile 'language (form-value "language"))))
			; Re-read configuration for user
			(user-edit))))

; Save user settings for certain profile
(define (profile-change)
  (let* ((user (f-get-ci-value "list_users"))
         (profile (f-get-ci-value "list_profiles_enabled"))
         (autostart (form-value "check_profile_autostart")))
    (catch/message (lambda()
                     (woo "users" "/rd/write_profile_options" 'user user 'profile profile 'autostart autostart 'language (form-value "language"))))))

; Disable profile for user
(define (profile-disable)
	(let*
		; Look profile name
		((profile (f-get-ci-value "list_profiles_enabled"))
		 ; Look user name
		 (user (f-get-ci-value "list_users")))
		(and
			; Disable profile for user
			(catch/message (lambda() (woo "users" "/rd/disable_profile" 'user user 'profile profile 'language (form-value "language"))))
			; Re-read configuration for user
			(user-edit))))

; Initialization routine
(define (init)
	; Buttons
	(form-bind "btn_profile_enable" "click" profile-enable)
	(form-bind "btn_profile_disable" "click" profile-disable)
	; Lists
	(form-bind "list_profiles_disabled" "change" disabled-selected)
	(form-bind "list_profiles_enabled" "change" enabled-selected)
	(form-bind "list_users" "change" user-edit)
	(form-bind "check_profile_autostart" "change" profile-change)
	; Interface initialization
	(init-interface))
